import { EntityBaseClass } from '../entity-base-class';
import { SDKRespond } from './../../services/modal/sdk-respond-interface';
import { BaseDeepVisibilityV2Request } from './modal/deep-visibility-v2-data-request.interface';
import { DeepVisibilityV2GetEventsRequest } from './modal/deep-visibility-v2-get-event-request.interface';
import { dv2EventType } from './modal/deep-visibility-v2-get-events-by-type-request.interface';
import { DeepVisibilityV2CreateQuery } from './modal/deep-visibility-v2-create-query.interface';
import { BaseDV2Query } from './base-dv-query.class';
import { ApiCall } from '../../services/api-call';
/**
 * Deep Visibility V2 - IOC
 *
 *  User Flow :
 *    1. createQuery() : queryId
 *    2. getQueryStatus(queryId): responseState ( Pulling every 2s ) /  cancelRunningQuery(queryId)
 *    3. getAllEvents()  | getEventsByType ()
 *
 *
 * @export
 * @class DeepVisibilityV2
 * @extends {EntityBaseClass}
 */
export declare class DeepVisibilityV2 extends EntityBaseClass {
    private apiCall;
    queryUtils: BaseDV2Query;
    constructor(apiCall: ApiCall);
    get(queryId: string): Promise<SDKRespond>;
    /**
     * Get Event Types
     *
     * GET: /web/api/v2.0/dv/count-by-type
     * Retrieve Deep Visibility events types from query
     *
     * @param {string} queryId
     * @param {string[]} [siteIds]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibilityV2
     */
    getEventTypes(queryId: string, siteIds?: string[]): Promise<SDKRespond>;
    /**
     * Get Distinct Fields Data
     *
     * @param {BaseDeepVisibilityV2Request} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibilityV2
     */
    getDistinctFieldsData(data: BaseDeepVisibilityV2Request): Promise<SDKRespond>;
    /**
     * Cancel Running Query
     *
     * POST : /web/api/v2.0/dv/cancel-query
     * Stop Deep Visibility Query by queryId
     * todo: should this function be available via the SDK?
     *
     * @param {string} queryId
     * @param {string[]} [siteIds]
     * @returns
     *
     * @memberOf DeepVisibilityV2
     */
    cancelRunningQuery(queryId: string, siteIds?: string[]): Promise<SDKRespond>;
    /**
     * Get All Events
     *
     * GET: /web/api/v2.0/dv/events
     * Retrieve all Deep Visibility events from query
     *
     * @param {DeepVisibilityV2GetEventsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibilityV2
     */
    getAllEvents(data: DeepVisibilityV2GetEventsRequest, interval: number): Promise<SDKRespond>;
    /**
     * Get Events By Type
     *
     * Retrieve Deep Visibility events from query by event type
     * GET: /web/api/v2.0/dv/events/{event_type}
     *
     * @param {dv2EventType} eventType
     * @param {DeepVisibilityV2GetEventsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibilityV2
     */
    getEventsByType(eventType: dv2EventType, data: DeepVisibilityV2GetEventsRequest): Promise<SDKRespond>;
    /**
     * Create Query
     *
     * Start Deep Visibility Query and get queryId
     * POST: /web/api/v2.0/dv/init-query
     *
     * @param {DeepVisibilityV2CreateQuery} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibilityV2
     */
    createQuery(data: DeepVisibilityV2CreateQuery): Promise<SDKRespond>;
    /**
     * Count By Type
     *
     * @param {string} queryId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibilityV2
     */
    countByType(queryId: string): Promise<SDKRespond>;
    /**
     * Get Recent Queries
     *
     * Retrieve 8 Recent Queries Run By User
     * GET : /web/api/v2.0/dv/queries
     *
     * @param {BaseDeepVisibilityV2Request} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibilityV2
     */
    getRecentQueries(data: BaseDeepVisibilityV2Request): Promise<SDKRespond>;
    /**
     * Get Query Status
     *
     * GET : /web/api/v2.0/dv/query-status
     * Retrieve Deep Visibility Query Status
     *
     * @param {string} queryId
     * @param {string[]} siteIds
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibilityV2
     */
    getQueryStatus(queryId: string, siteIds?: string[]): Promise<SDKRespond>;
    /**
     * Get Available Actions
     * GET: /web/api/v2.0/dv/available-actions
     *
     * @param {BaseDeepVisibilityV2Request} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibilityV2
     */
    getAvailableActions(data: BaseDeepVisibilityV2Request): Promise<SDKRespond>;
    /**
     * Pull Query State
     *
     * @param {number} timePeriod
     * @param {any} queryID
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibilityV2
     */
    pullQueryState(queryId: string, timePeriod: number, callBack?: any): Promise<SDKRespond>;
    /**
     * Set Pulling Interval
     *
     * called right after createQuery function ,
     * basiclly this method gets the query status every (timePeriod) ms
     * and by defualts call getAllEvents right after FINISH status recived
     * otherwise adiitional param needed , when calling this method
     *
     * @private
     * @param {string} queryId
     * @param {number} timePeriod
     * @returns {Promise<any>}
     *
     * @memberOf DeepVisibilityV2
     */
    private setPullingInterval;
    /**
     * Pulling Status
     *
     * @private
     * @param {Dv2RespondStateTypes} responseState
     * @param {string} queryId
     * @param {*} interval
     * @param {number} timePeriod
     * @returns {Promise<any>}
     *
     * @memberOf DeepVisibilityV2
     */
    private PullingStatus;
    /**
     * Keep Running
     *
     * @private
     * @param {*} startTime
     * @param {*} eventCought
     * @param {any} MAX_TIME_OUT
     * @param {any} interval
     * @returns
     *
     * @memberOf DeepVisibilityV2
     */
    private keepPulling;
    /**
     * End Pulling
     *
     * @private
     * @param {*} interval
     * @param {string} resultDueTo
     * @returns
     *
     * @memberOf DeepVisibilityV2
     */
    private endPulling;
    /**
     * Is Time Out
     *
     * checks if pulling reached the maximum time allowed
     * since first request was called (10s by defualt)
     *
     * @private
     * @param {any} passedTime
     * @param {any} startTime
     * @param {any} maxTime
     * @param {any} interval
     * @returns
     *
     * @memberOf DeepVisibilityV2
     */
    private isTimeOut;
}
