import { EntityBaseClass } from '../entity-base-class';
import { ApiCall } from '../../services/api-call';
import { DeviceControlRequest } from './modal/device-control-request.interface';
import { DeviceControlExtendedRequest } from './modal/device-control-extended-request.interface';
import { BaseScope } from '../../model/scope-get.interface';
import { DeviceControlUpdateConfigurationRequest } from './modal/device-control-update-configurtion-request.interface';
import { DeviceControlAddUpdateRuleRequest } from './modal/device-control-add-update-rule-request.interface';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
/**
 * Device Control
 * Blog post: https://www.sentinelone.com/blog/feature-spotlight-device-control/
 *
 * LTE:
 * An almost universal feature of every endpoint is the ability to plug in USBs and other peripheral devices.
 * Businesses need that flexibility, but plug-in devices introduce a vulnerability to enterprise security.
 * Whether it’s a poisoned device containing malware, or simply a route for disgruntled employees to steal and distribute company data,
 * external devices are essentially a blind spot for the enterprise.
 *
 * @export
 * @class DeviceControl
 * @extends {EntityBaseClass}
 */
export declare class DeviceControl extends EntityBaseClass {
    constructor(apiCall: ApiCall);
    /**
     * Get
     *
     * @param {Partial<DeviceControlExtendedRequest>} [data]
     * @param {*} [filter]
     * @returns {Promise<any>}
     * @memberof DeviceControl
     */
    get(data?: Partial<DeviceControlExtendedRequest>, filter?: any): Promise<any>;
    /**
     * Get Events
     *
     * GET: /web/api/v2.0/device-control/events
     * Get a list of device control events reported by agents
     *
     * @param {DeviceControlRequest} [data]
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    getEvents(data?: DeviceControlRequest): Promise<SDKRespond>;
    /**
     * Count By Filters
     *
     * GET: /web/api/v2.0/private/device-control/filters-count
     * Show a count of threats per filter value.
     *
     * @param {DeviceControlExtendedRequest} data
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    countByFilters(data: DeviceControlExtendedRequest): Promise<SDKRespond>;
    /**
     * Get Interfaces
     *
     * GET : /web/api/v2.0/private/device-control/interfaces
     * Get interfaces and classes data.
     *
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    getInterfaces(): Promise<SDKRespond>;
    /**
     * Get Unscoped Rules
     *
     * GET: /web/api/v2.0/private/device-control/unscoped
     * Get a list of device control rules, may be of mixed scopes (depending on the provided query arguments)
     *
     * @param {DeviceControlExtendedRequest} data
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    getUnscopedRules(data?: DeviceControlExtendedRequest): Promise<SDKRespond>;
    /**
     * Get Configuration
     *
     * GET: /web/api/v2.0/device-control/configuration
     * Get device control configuration for a given scope
     *
     * @param {Partial<BaseScope>} data
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    getConfiguration(data: Partial<BaseScope>): Promise<SDKRespond>;
    /**
     * Update Configuration
     *
     * PUT: /web/api/v2.0/device-control/configuration
     * Update device control configuration for a given scope
     *
     * @param {Partial<BaseScope>} filter
     * @param {DeviceControlUpdateConfigurationRequest} data
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    updateConfiguration(filter: Partial<BaseScope>, data: DeviceControlUpdateConfigurationRequest): Promise<SDKRespond>;
    /**
     * Copy Rules
     *
     * POST: /web/api/v2.0/device-control/copy-rules
     * Copies a set of rules to other scopes
     *
     * @param {DeviceControlExtendedRequest} filter
     * @param {{ siteId: string; groupIds?: string[] }} data
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    copyRules(filter: DeviceControlExtendedRequest, data: {
        siteId: string;
        groupIds?: string[];
    }): Promise<SDKRespond>;
    /**
     * Reorder Rules
     *
     * PUT:/web/api/v2.0/device-control/reorder
     * Change order of rules for a specific scope
     *
     * @param {Partial<BaseScope>} filter
     * @param {{ id: string; order: number }} data
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    reorderRules(filter: Partial<BaseScope>, data: {
        id: string;
        order: number;
    }): Promise<SDKRespond>;
    /**
     * Export Rules
     *
     * GET: /web/api/v2.0/device-control/export
     * Export device control rules to CSV file
     *
     * @param {DeviceControlExtendedRequest} data
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    exportRules(data: DeviceControlExtendedRequest): Promise<SDKRespond>;
    /**
     * Import Rules
     *
     * POST: /web/api/v2.0/device-control/import
     * Import device control rules from a CSV file
     *
     * @param {Partial<BaseScope>} data
     * @param {object} file
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    importRules(data: Partial<BaseScope>, file: object): Promise<SDKRespond>;
    /**
     * Enable Disable Rules
     *
     * PUT:/web/api/v2.0/device-control/enable
     * Change status of a set of rules to "Enabled" or "Disabled"
     *
     * @param {DeviceControlExtendedRequest} filter
     * @param {({ status: 'Disabled' | 'Enabled' })} data
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    enableDisableRules(filter: DeviceControlExtendedRequest, data: {
        status: 'Disabled' | 'Enabled';
    }): Promise<SDKRespond>;
    /**
     * Delete Rules
     *
     * DELETE: /web/api/v2.0/device-control
     * Deletes rules based on a filter
     *
     * @param {DeviceControlExtendedRequest} filter
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    deleteRules(filter: DeviceControlExtendedRequest): Promise<SDKRespond>;
    /**
     * Get Device Rules
     *
     * GET: /web/api/v2.0/device-control
     * Get a list of device rules for a given scope
     *
     * @param {DeviceControlExtendedRequest} data
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    getDeviceRules(data: DeviceControlExtendedRequest): Promise<SDKRespond>;
    /**
     * Create Device Rule
     *
     * POST: /web/api/v2.0/device-control
     * Create a new device rule
     *
     * @param {Partial<BaseScope>} filter
     * @param {DeviceControlAddUpdateRuleRequest} data
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    createDeviceRule(filter: Partial<BaseScope>, data: DeviceControlAddUpdateRuleRequest): Promise<SDKRespond>;
    /**
     * Update Device Rule
     *
     * PUT: /web/api/v2.0/device-control/{rule_id}
     * Update an existing device rule
     *
     * @param {string} ruleId
     * @param {DeviceControlAddUpdateRuleRequest} data
     * @returns {Promise<SDKRespond>}
     * @memberof DeviceControl
     */
    updateDeviceRule(ruleId: string, data: DeviceControlAddUpdateRuleRequest): Promise<SDKRespond>;
}
