import { BaseClass } from '../model/base.interface';
import { SDKRespond } from '../services/modal/sdk-respond-interface';
import { GetEntityError } from '../errors/get-error-class';
import { HttpMethod } from '../enums/http-method';
import { ApiCall } from '../services/api-call';
import { CreateEntityError } from '../errors/create-error-class';
import { ApiUrlQueries } from './modal/api-url-queries.interface';
import { UpdateEntityError } from '../errors/update-error-class';
import { DeleteEntityError } from '../errors/delete-error-class';
/**
 * EntityBaseClass
 *
 * @export
 * @abstract
 * @class EntityBaseClass
 * @implements {BaseClass}
 */
export declare abstract class EntityBaseClass implements BaseClass {
    endPoints: any;
    entityName: string;
    private request;
    protected constructor(endPoints: object, entityName: string, request: ApiCall);
    /** get() should be implamented for every entity with defualt method */
    abstract get(data?: any): Promise<any>;
    /**
     * Make Api Call
     *
     * this is implementation for apiCall.makeApiCall(...),
     * to be use on the extending class.
     * making the code much shorter and cleaner.
     *
     * There is two ways to send data :
     *  1. make an object by the method's interface
     *  2. RequestData<interface>(<data>)
     *
     * In addition we handel a case that
     *  - An additional data (like user_id) should be add to the url endpoint (see ApiUrlQueries inteface).
     *    In this case the url will be a function that accept the params needed to be added.
     *
     *
     * @param {string} endpointName
     * @param {*} [data]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf EntityBaseClass
     */
    makeApiCall(endpointName: string, data?: any): Promise<SDKRespond>;
    /**
     * Error Handler
     *
     * used in makeApiCall method ,
     * Returns an Error by the HTTP METHOD TYPE (GET, POST ETC...)
     *
     * @param {HttpMethod} reqMethode
     * @param {any} endpointName
     * @param {any} error
     * @returns :
     * GetEntityError | CreateEntityError | UpdateEntityError | DeleteEntityError
     *
     * @memberOf EntityBaseClass
     */
    protected errorHandler(reqMethode: HttpMethod, endpointName: any, error: any): GetEntityError | CreateEntityError | UpdateEntityError | DeleteEntityError;
    /**
     * Prepare Api Url Queries
     *
     * this function returns an object with the SDKstandart's structure ,
     * so later on data will be added to the url
     *
     * Example: /web/api/v2.0/users/{user_id} (userId = "523"):
     *    1. userId is sent as a query param (can be in all rest types) in the api call
     *    2. userId is passed to prepareApiUrlQueries([userId])
     *       Retuns ApiUrlQueries { payloadQuery:["523"] } (for farther processing)
     *
     * @protected
     * @param {any[]} data
     * @returns {ApiUrlQueries}
     *
     * @memberOf EntityBaseClass
     */
    protected prepareApiUrlQueries(data: any[]): ApiUrlQueries;
    /**
     * Attach Query Params
     *
     * @private
     * @param {*} url
     * @param {*} data
     * @returns
     *
     * @memberOf EntityBaseClass
     */
    private attachQueryParams;
    /**
     * Attach Query Params If Needed
     *
     *  - called from makeApiCall
     *  - extract Query Params
     *  - attach it to the url by calling url() function
     *
     * @param url : any
     * @param data
     * Returns: new url with the appended data
     */
    private attachQueryParamsIfNeeded;
    /**
     * Delete PayloadQuery
     * After appending the relavent data to the url we simply  remove it from the data object
     *
     * @param {any} data
     *
     * @memberOf EntityBaseClass
     */
    private deletePayloadQuery;
}
