import { EntityBaseClass } from '../entity-base-class';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
import { ApiCall } from '../../services/api-call';
import { GetFWControlRequest } from './modal/get-fw-control-rules.interface';
import { UpdateFirewallRullRequest } from './modal/update-firewall-rull-request.interface';
import { BaseScope } from '../../model/scope-get.interface';
import { BaseGetQueryParams } from '../../model/base-get.interface';
import { ExtendedGetFwRequest } from './modal/extended-get-fw-request.interface';
import { OsTypes } from '../..';
/**
 * Firewall Control
 *
 * Blog post: https://www.sentinelone.com/blog/feature-spotlight-firewall-control/
 *
 * LTE
 * Consider the following scenario:
 * IT gets an intelligence feed indicating that a specific phishing URL is scraping credentials globally.
 * To protect users on the network, administrators immediately add a rule to the network firewall to block the URL.
 * But what about remote users not behind the firewall? And what if the perimeter protection fails or is circumvented?
 *
 */
export declare class FirewallControl extends EntityBaseClass {
    constructor(apiCall: ApiCall);
    /**
     * Get
     *
     * gets firewall data:
     *  - rules
     *  - unscoped rules
     *  - configuration
     *  - protocols
     *
     * @returns {Promise<any>}
     * @memberof FirewallControl
     */
    get(data?: any): Promise<any>;
    /**
     * Get Firewall Rules
     *
     * GET : /web/api/v2.0/firewall-control
     * Get a list of firewall rules for a given scope
     *
     * @param {GetFWControlRequest} [data]
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    getFirewallRules(data?: GetFWControlRequest): Promise<SDKRespond>;
    /**
     * Update Firewall Rule
     *
     * PUT: /web/api/v2.0/firewall-control/{ruleId}
     * Update an existing firewall rule
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    updateFirewallRule(ruleId: string, data?: UpdateFirewallRullRequest): Promise<SDKRespond>;
    /**
     * Get Unscoped Rules
     *
     * GET: /web/api/v2.0/private/firewall-control/unscoped
     * Get a list of firewall rules, may be of mixed scopes (depending on the provided query arguments)
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    getUnscopedRules(data?: GetFWControlRequest): Promise<SDKRespond>;
    /**
     * Update Configuration
     *
     * PUT: /web/api/v2.0/firewall-control/configuration
     * Update firewall control configuration for a given scope
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    updateConfiguration(filter?: any, data?: any): Promise<SDKRespond>;
    /**
     * Move Rules
     *
     * POST: /web/api/v2.0/firewall-control/move-rules
     * Moves a set of rules ids to new scopes
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    moveRules(filter?: GetFWControlRequest, data?: BaseScope): Promise<SDKRespond>;
    /**
     * Reorder Rules
     *
     * PUT: /web/api/v2.0/firewall-control/reorder
     * Change order of rules for a specific scope
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    reorderRules(filter: Partial<BaseScope>, osTypes: OsTypes[], data: {
        id: string;
        order: number;
    }): Promise<SDKRespond>;
    /**
     * Create Firewall Rule
     *
     * POST: /web/api/v2.0/firewall-control
     * Create a new firewall rule
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    createFirewallRule(filter?: Partial<BaseScope>, data?: UpdateFirewallRullRequest): Promise<SDKRespond>;
    /**
     * Create NQ Rule
     *
     * POST: /web/api/v2.0/firewall-control/network-quarantine
     * Create a new NQ rule
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    createNetworkQuarantineRule(filter?: Partial<BaseScope>, data?: UpdateFirewallRullRequest): Promise<SDKRespond>;
    /**
     * Count By Filters
     *
     * GET: /web/api/v2.0/private/firewall-control/filters-count
     * Show a count of threats per filter value.
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    countByFilters(data?: GetFWControlRequest): Promise<SDKRespond>;
    /**
     * Get Configuration
     *
     * GET: /web/api/v2.0/firewall-control/configuration
     * Get firewall control configuration for a given scope
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    getConfiguration(data?: Partial<BaseScope>): Promise<SDKRespond>;
    /**
     * Copy Rules
     *
     * POST:/web/api/v2.0/firewall-control/copy-rules
     * Copies a set of rules to other scopes
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    copyRules(data: Partial<BaseScope>, filter: GetFWControlRequest): Promise<SDKRespond>;
    /**
     * Get Protocols
     *
     * GET: /web/api/v2.0/firewall-control/protocols
     * Get a list of firewall protocols
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    getProtocols(data?: BaseGetQueryParams): Promise<SDKRespond>;
    /**
     * Export Rules
     *
     * GET: /web/api/v2.0/firewall-control/export
     * Export firewall rules to JSON file
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    exportRules(data: GetFWControlRequest): Promise<SDKRespond>;
    /**
     * Import Rules
     *
     * POST: /web/api/v2.0/firewall-control/import
     * Import firewall rules from a JSON file
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    importRules(scope: BaseScope, file: object): Promise<SDKRespond>;
    /**
     * Enable Disable Rules
     *
     * PUT: /web/api/v2.0/firewall-control/enable
     * Change status of a set of rules to "Enabled" or "Disabled"
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    enableDisableRules(data: {
        status: 'Disabled' | 'Enabled';
    }, filter: ExtendedGetFwRequest): Promise<SDKRespond>;
    /**
     * Delete Rules
     *
     * @returns {Promise<SDKRespond>}
     * @memberof FirewallControl
     */
    deleteRules(filter: GetFWControlRequest): Promise<SDKRespond>;
}
